@@ -796,7 +796,7 @@ struct test_walker: xml_tree_walker
 	{
 		char buf[32];
 
-	#if __cplusplus >= 201103
+	#if __cplusplus >= 201103 || defined(__APPLE__) // Xcode 14 warns about use of sprintf in C++98 builds
 		snprintf(buf, sizeof(buf), "%d", depth());
 	#else
 		sprintf(buf, "%d", depth());
