@@ -1252,6 +1252,112 @@ TEST_XML_FLAGS(parse_embed_pcdata_comment, "<n>text1<!---->text2</n>", parse_emb
 	CHECK_STRING(n.last_child().value(), STR("text2"));
 }
 
+TEST(parse_merge_pcdata)
+{
+	unsigned int flag_sets[] = {parse_cdata, parse_pi, parse_comments, parse_declaration};
+
+	for (unsigned int i = 0; i < sizeof(flag_sets) / sizeof(flag_sets[0]); ++i)
+	{
+		unsigned int flags = parse_merge_pcdata | flag_sets[i];
+
+		xml_document doc;
+		xml_parse_result res = doc.load_string(STR("<node>First text<!-- here is a mesh node -->Second text<![CDATA[someothertext]]>some more text<?include somedata?>Last text</node>"), flags);
+		CHECK(res);
+
+		xml_node child = doc.child(STR("node"));
+
+		if (flags & parse_comments)
+		{
+			CHECK_STRING(child.first_child().value(), STR("First text"));
+			CHECK(child.first_child().next_sibling().type() == node_comment);
+			CHECK_NODE(doc, STR("<node>First text<!-- here is a mesh node -->Second textsome more textLast text</node>"));
+		}
+		else if (flags & parse_cdata)
+		{
+			CHECK_STRING(child.first_child().value(), STR("First textSecond text"));
+			CHECK(child.first_child().next_sibling().type() == node_cdata);
+			CHECK_NODE(doc, STR("<node>First textSecond text<![CDATA[someothertext]]>some more textLast text</node>"));
+		}
+		else if (flags & parse_pi)
+		{
+			CHECK_STRING(child.first_child().value(), STR("First textSecond textsome more text"));
+			CHECK(child.first_child().next_sibling().type() == node_pi);
+			CHECK_NODE(doc, STR("<node>First textSecond textsome more text<?include somedata?>Last text</node>"));
+		}
+		else
+		{
+			CHECK(child.first_child() == child.last_child());
+			CHECK(child.first_child().type() == node_pcdata);
+			CHECK_NODE(doc, STR("<node>First textSecond textsome more textLast text</node>"));
+		}
+
+		CHECK(child.last_child().type() == node_pcdata);
+	}
+}
+
+TEST(parse_merge_pcdata_escape)
+{
+	xml_document doc;
+	xml_parse_result res = doc.load_string(STR("<node>First &amp;lt; <!-- comment 1 --> Second &amp;gt; <!-- comment 2 --> Third &amp;quot;</node>"), parse_default | parse_merge_pcdata);
+	CHECK(res);
+
+	CHECK_STRING(doc.child(STR("node")).child_value(), STR("First &lt;  Second &gt;  Third &quot;"));
+}
+
+TEST(parse_merge_pcdata_whitespace)
+{
+	unsigned int flag_sets[] = {0, parse_ws_pcdata, parse_ws_pcdata_single};
+
+	for (unsigned int i = 0; i < sizeof(flag_sets) / sizeof(flag_sets[0]); ++i)
+	{
+		unsigned int flags = parse_merge_pcdata | flag_sets[i];
+
+		xml_document doc;
+		xml_parse_result res = doc.load_string(STR("<node><child1>  <!-- comment 1 -->\t<!-- comment 2 -->\n</child1><child2>text<!-- comment 1-->\t<!-- comment2 --> end</child2></node>"), flags);
+		CHECK(res);
+
+		if (flags & parse_ws_pcdata)
+		{
+			CHECK_STRING(doc.child(STR("node")).child(STR("child1")).child_value(), STR("  \t\n"));
+			CHECK_STRING(doc.child(STR("node")).child(STR("child2")).child_value(), STR("text\t end"));
+		}
+		else if (flags & parse_ws_pcdata_single)
+		{
+			CHECK_STRING(doc.child(STR("node")).child(STR("child1")).child_value(), STR("\n"));
+			CHECK_STRING(doc.child(STR("node")).child(STR("child2")).child_value(), STR("text end"));
+		}
+		else
+		{
+			CHECK(!doc.child(STR("node")).child(STR("child1")).first_child());
+			CHECK_STRING(doc.child(STR("node")).child(STR("child2")).child_value(), STR("text end"));
+		}
+	}
+}
+
+TEST(parse_merge_pcdata_append)
+{
+	xml_document doc;
+	doc.append_child(STR("node")).append_child(node_pcdata);
+	xml_parse_result res = doc.child(STR("node")).append_buffer("hello <!--comment-->world", 25, parse_merge_pcdata | parse_fragment);
+
+	CHECK(res.status == status_append_invalid_root);
+	CHECK_STRING(doc.child(STR("node")).first_child().value(), STR(""));
+
+	doc.child(STR("node")).remove_children();
+	res = doc.child(STR("node")).append_buffer("hello <!--comment-->world", 25, parse_merge_pcdata | parse_fragment);
+
+	CHECK(res.status == status_ok);
+	CHECK_STRING(doc.child(STR("node")).first_child().value(), STR("hello world"));
+}
+
+TEST(parse_merge_pcdata_overlap)
+{
+	xml_document doc;
+	xml_parse_result res = doc.load_string(STR("<node>short <!-- --> this string is very long so long that copying it will overlap itself</node>"), parse_merge_pcdata);
+	CHECK(res);
+	CHECK_STRING(doc.child_value(STR("node")), STR("short  this string is very long so long that copying it will overlap itself"));
+}
+
 TEST(parse_encoding_detect)
 {
 	char test[] = "<?xml version='1.0' encoding='utf-8'?><n/>";
